var searchData=
[
  ['h_5fa_5fdisproof',['h_a_disproof',['../classosl_1_1ntesuki_1_1NtesukiMove.html#af2abdf07f90037dca15ed0b25cffb3f5',1,'osl::ntesuki::NtesukiMove']]],
  ['h_5fa_5fproof',['h_a_proof',['../classosl_1_1ntesuki_1_1NtesukiMove.html#a37c02d03bb4f8b58aaa8c530155f6177',1,'osl::ntesuki::NtesukiMove']]],
  ['h_5fd_5fdisproof',['h_d_disproof',['../classosl_1_1ntesuki_1_1NtesukiMove.html#afff65005ca4e04c0d29f6d1496838068',1,'osl::ntesuki::NtesukiMove']]],
  ['h_5fd_5fproof',['h_d_proof',['../classosl_1_1ntesuki_1_1NtesukiMove.html#a2ecb8921868e28e51a19e26190e1d135',1,'osl::ntesuki::NtesukiMove']]],
  ['hand_5fptype',['hand_ptype',['../structosl_1_1annotate_1_1AnalysesResult_1_1ThreatmateIfMorePieces.html#a6680c48669cd3d2a7071db7f62cb41ac',1,'osl::annotate::AnalysesResult::ThreatmateIfMorePieces']]],
  ['has_5fbyoyomi',['has_byoyomi',['../classosl_1_1game__playing_1_1SpeculativeAllMoves.html#a5e489d1e6965d80a3da14f86adbf54e2',1,'osl::game_playing::SpeculativeAllMoves::has_byoyomi()'],['../structosl_1_1OslConfig.html#aa61dbbb14f9816d2277cd97d21eae0cd',1,'osl::OslConfig::has_byoyomi()'],['../structosl_1_1game__playing_1_1SpeculativeAllMoves_1_1SearchAllMoves_1_1Generator.html#aa695be82af5c791a9b4e1f1771df21a8',1,'osl::game_playing::SpeculativeAllMoves::SearchAllMoves::Generator::has_byoyomi()']]],
  ['has_5feffect',['has_effect',['../structosl_1_1checkmate_1_1ProofNumberTable_1_1Liberty.html#a9b794364cb93ea14577fba65249276f9',1,'osl::checkmate::ProofNumberTable::Liberty::has_effect()'],['../classosl_1_1rating_1_1BadLance.html#af0188699f58875aec6068f2df5736944',1,'osl::rating::BadLance::has_effect()']]],
  ['has_5flong',['has_long',['../classosl_1_1move__action_1_1EscapeFilter.html#a4d99234448b0a0165c6918ee150dd950',1,'osl::move_action::EscapeFilter']]],
  ['has_5flong_5fsupport',['has_long_support',['../classosl_1_1move__action_1_1EscapeFilter.html#a9e4afb9bceb2353f4e1f34aa251d45b2',1,'osl::move_action::EscapeFilter']]],
  ['has_5fsafe_5fescape',['has_safe_escape',['../structosl_1_1search_1_1QSearch2SafeEscape.html#a4367f16d1d2e1e874cdad318b43933ea',1,'osl::search::QSearch2SafeEscape']]],
  ['has_5funblockable_5feffect',['has_unblockable_effect',['../structosl_1_1effect__util_1_1Neighboring8Direct_1_1Table_1_1Entry.html#ac432d45eb1a3c4e2ce5e92a35e8ff15d',1,'osl::effect_util::Neighboring8Direct::Table::Entry::has_unblockable_effect()'],['../structosl_1_1effect__util_1_1Neighboring8Effect_1_1Table_1_1Entry.html#acd0f85e9a6acc6e8e3fac2f172be9886',1,'osl::effect_util::Neighboring8Effect::Table::Entry::has_unblockable_effect()']]],
  ['hash1',['hash1',['../classosl_1_1hash_1_1HashKeyMix.html#a261f3705f94eba5c483d7c0ff89e2753',1,'osl::hash::HashKeyMix']]],
  ['hash2',['hash2',['../classosl_1_1hash_1_1HashKeyMix.html#a3191dc99948d0e3ca8f6a3581dfb425a',1,'osl::hash::HashKeyMix']]],
  ['hash_5fgen_5ftable',['Hash_Gen_Table',['../namespaceosl_1_1hash.html#aaf0d1e437fc31d45836e85e005330948',1,'osl::hash']]],
  ['hash_5fhistory',['hash_history',['../classosl_1_1RepetitionCounter.html#acff71d9a165ee5301c1cae9b2a5c9df2',1,'osl::RepetitionCounter']]],
  ['hash_5fkey',['hash_key',['../structosl_1_1search_1_1AlphaBeta3_1_1SearchInfo.html#a2ffa6389907e8ad65faa99a2ace595b2',1,'osl::search::AlphaBeta3::SearchInfo::hash_key()'],['../structosl_1_1checkmate_1_1Dfpn_1_1NodeBase.html#a7322a567da2d218975f9db90c9ce4edc',1,'osl::checkmate::Dfpn::NodeBase::hash_key()']]],
  ['hashes',['hashes',['../structosl_1_1checkmate_1_1Dfpn_1_1Node.html#a1bd441f243b17ce164fb8c85cd1a4f3f',1,'osl::checkmate::Dfpn::Node']]],
  ['hashmajorpawn',['HashMajorPawn',['../structosl_1_1hash_1_1HashKey128_1_1StandHash.html#a089942651fb3aee58094853d53e46f2c',1,'osl::hash::HashKey128::StandHash']]],
  ['hashpiece',['HashPiece',['../structosl_1_1hash_1_1HashKey128_1_1StandHash.html#a147fdda4dfbf182cf9e1d7a157358b33',1,'osl::hash::HashKey128::StandHash']]],
  ['haslongmove',['hasLongMove',['../structosl_1_1PtypeFuns.html#af4407ddc1ce09693388464fb4da4fabf',1,'osl::PtypeFuns']]],
  ['hasmove',['hasMove',['../structosl_1_1PtypeDirectionTraits.html#a202eab073ea9de0a8f73e1499afb7bc8',1,'osl::PtypeDirectionTraits']]],
  ['haspawnmask',['hasPawnMask',['../classosl_1_1state_1_1SimpleState.html#acf43ab89bf409164f1f9355a4dd0643f',1,'osl::state::SimpleState']]],
  ['head_5ftable',['head_table',['../classosl_1_1eval_1_1ml_1_1SilverFeatures.html#a2762e2d6292dec70f9c6609eed994aff',1,'osl::eval::ml::SilverFeatures']]],
  ['header',['header',['../csa-to-kifu_8cc.html#a6199d57983f8365cd3411a201a9c5217',1,'csa-to-kifu.cc']]],
  ['header_5fsize',['HEADER_SIZE',['../classosl_1_1record_1_1opening_1_1WeightedBook.html#a0b6e841494a68a2e6cae3134952ff0ad',1,'osl::record::opening::WeightedBook']]],
  ['height',['height',['../structosl_1_1search_1_1AlphaBeta3_1_1PVInfo.html#a5002d2432015ecbb978ef6f6514758bd',1,'osl::search::AlphaBeta3::PVInfo::height()'],['../structosl_1_1search_1_1AlphaBeta3_1_1SearchInfo.html#a8c826d749dd50564684b76dd6bb77530',1,'osl::search::AlphaBeta3::SearchInfo::height()']]],
  ['histogram',['histogram',['../probability_8cc.html#a37c18705c686f6c75520d1e7dc9c6a0b',1,'probability.cc']]],
  ['histograms',['histograms',['../structHistogram8.html#a64478b8a5fdff1574b5a19b57d9a3470',1,'Histogram8']]],
  ['history',['history',['../structosl_1_1move__probability_1_1StateInfo.html#a724c6e3ac03d16e19f4f63b273ad69e2',1,'osl::move_probability::StateInfo::history()'],['../classosl_1_1rating_1_1RatingEnv.html#a5285408299c93aa85f2eb4e4368286ea',1,'osl::rating::RatingEnv::history()']]],
  ['history_5ftable',['history_table',['../structosl_1_1search_1_1SearchState2Shared.html#a4a9f521ef59721d35d388b770ed9cb8e',1,'osl::search::SearchState2Shared']]],
  ['historyspecialdepth',['HistorySpecialDepth',['../structosl_1_1search_1_1SearchTable.html#af3d4959645808be024bdcf63bb8cb934',1,'osl::search::SearchTable']]]
];
